==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/hooks/useQuery.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/hooks/useQuery.es", ['module', 'exports', 'require', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.toQueryString = exports.toQuery = void 0;

  var _react = require("frontend-js-react-web$react");

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var toQuery = function toQuery(string) {
    var defaultQuery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    var query = _objectSpread({}, defaultQuery);

    var params = new URLSearchParams(string);
    params.forEach(function (value, key) {
      query[key] = value;
    });
    return query;
  };

  exports.toQuery = toQuery;

  var toQueryString = function toQueryString(object) {
    var queryString = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    var params = new URLSearchParams(queryString);
    Object.keys(object).forEach(function (key) {
      if (object[key]) {
        params.set(key, object[key]);
      } else {
        params["delete"](key);
      }
    });
    return params.toString();
  };

  exports.toQueryString = toQueryString;

  var _default = function _default(history) {
    var defaultQuery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var location = history.location;
    var pathname = location.pathname,
        search = location.search;
    var defaultQueryRef = (0, _react.useRef)(defaultQuery);

    var _useState = (0, _react.useState)(toQuery(search, defaultQueryRef.current)),
        _useState2 = _slicedToArray(_useState, 2),
        query = _useState2[0],
        setQuery = _useState2[1];

    (0, _react.useEffect)(function () {
      setQuery(toQuery(search, defaultQueryRef.current));
    }, [defaultQueryRef, search]);
    return [query, function (query) {
      return history.push("".concat(pathname, "?").concat(toQueryString(query, search)));
    }];
  };

  exports["default"] = _default;
  //# sourceMappingURL=useQuery.es.js.map
});
//# sourceMappingURL=useQuery.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/hooks/useQuery.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/hooks/useQuery.es", ['module', 'exports', 'require', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.toQueryString = exports.toQuery = void 0;

  var _react = require("frontend-js-react-web$react");

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var toQuery = function toQuery(string) {
    var defaultQuery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    var query = _objectSpread({}, defaultQuery);

    var params = new URLSearchParams(string);
    params.forEach(function (value, key) {
      if (!isNaN(value)) {
        value = parseInt(value, 10);
      }

      query[key] = value;
    });
    return query;
  };

  exports.toQuery = toQuery;

  var toQueryString = function toQueryString(object) {
    var queryString = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    var params = new URLSearchParams(queryString);
    Object.keys(object).forEach(function (key) {
      if (object[key]) {
        params.set(key, object[key]);
      } else {
        params["delete"](key);
      }
    });
    return params.toString();
  };

  exports.toQueryString = toQueryString;

  var _default = function _default(history) {
    var defaultQuery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var location = history.location;
    var pathname = location.pathname,
        search = location.search;
    var defaultQueryRef = (0, _react.useRef)(defaultQuery);

    var _useState = (0, _react.useState)(toQuery(search, defaultQueryRef.current)),
        _useState2 = _slicedToArray(_useState, 2),
        query = _useState2[0],
        setQuery = _useState2[1];

    (0, _react.useEffect)(function () {
      setQuery(toQuery(search, defaultQueryRef.current));
    }, [defaultQueryRef, search]);
    return [query, function (query) {
      return history.push("".concat(pathname, "?").concat(toQueryString(query, search)));
    }];
  };

  exports["default"] = _default;
  //# sourceMappingURL=useQuery.es.js.map
});
//# sourceMappingURL=useQuery.es.js.map
